Shopyoapi
=========

Shopyo has some api which eases your life

shopyoapi.cmd
-------------

.. automodule:: shopyoapi.cmd
    :members:
    :undoc-members:
    :inherited-members:
    :show-inheritance:

shopyoapi.database
------------------

.. automodule:: shopyoapi.database
    :members:
    :undoc-members:
    :inherited-members:
    :show-inheritance:

shopyoapi.enhance
-----------------

.. automodule:: shopyoapi.enhance
    :members:
    :undoc-members:
    :inherited-members:
    :show-inheritance:

shopyoapi.file
--------------

.. automodule:: shopyoapi.file
    :members:
    :undoc-members:
    :inherited-members:
    :show-inheritance:



shopyoapi.forms
---------------

.. automodule:: shopyoapi.forms
    :members:
    :undoc-members:
    :inherited-members:
    :show-inheritance:

shopyoapi.html
--------------

.. automodule:: shopyoapi.html
    :members:
    :undoc-members:
    :inherited-members:
    :show-inheritance:

shopyoapi.info
--------------

.. automodule:: shopyoapi.info
    :members:
    :undoc-members:
    :inherited-members:
    :show-inheritance:


shopyoapi.init
--------------

.. automodule:: shopyoapi.init
    :members:
    :undoc-members:
    :inherited-members:
    :show-inheritance:


shopyoapi.module
-----------------

.. automodule:: shopyoapi.module
    :members:
    :undoc-members:
    :inherited-members:
    :show-inheritance: